<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Admin Actions Log Exclude Logging
 */

namespace Amasty\AdminActionsLogExcludeLogging\Logging\ActionType\Validation;

use Amasty\AdminActionsLog\Api\Logging\MetadataInterface;
use Amasty\AdminActionsLog\Logging\ActionType\Validation\ActionValidatorInterface;
use Amasty\AdminActionsLog\Logging\Util\ClassNameNormalizer;
use Amasty\AdminActionsLogExcludeLogging\Model\ConfigProvider;

class EntityValidator implements ActionValidatorInterface
{
    /**
     * @var ConfigProvider
     */
    private $configProvider;

    /**
     * @var ClassNameNormalizer
     */
    private $classNameNormalizer;

    public function __construct(
        ConfigProvider $configProvider,
        ClassNameNormalizer $classNameNormalizer
    ) {
        $this->configProvider = $configProvider;
        $this->classNameNormalizer = $classNameNormalizer;
    }

    public function isValid(MetadataInterface $metadata): bool
    {
        $list = $this->configProvider->getExcludedEntityList();
        $class = get_class($metadata->getObject());
        $className = $this->classNameNormalizer->execute($class);

        return !in_array($className, $list);
    }
}
